@@ -4,9 +4,10 @@
 
 from lazyearth.mainfile import objearth
 from lazyearth.mainfile import water
+from lazyearth.mainfile import imagedataset
 
 deving_by = 'tul kedsaro'
 
-__version__ = '1.0.14'
-print(f'Lazyearth version : {__version__} Kub')
+__version__ = '1.0.16'
+print(f'Lazyearth version : {__version__} Krub')
 
