@@ -411,6 +411,11 @@ class objearth():
         sigma, mu = 0.5, 1.0
         g = numpy.exp(-( (d-mu)**2 / ( 2.0 * sigma**2 ) ) )
         return g
+
+    # def _inter_from_256(x):
+    #     return np.interp(x=x,xp=[0,255],fp=[0,1])
+    # def __rgb_to_colormapcode(r,g,b):
+    #     return (_inter_from_256(r),_inter_from_256(g),_inter_from_256(b))
     
     @staticmethod
     def bluesea():
@@ -1448,4 +1453,28 @@ class imagedataset(objearth,water):
             if z:
                 objearth.plotshow(od[k][0],figsize=(6,6),title=od[k][1],area=z['area'])
             else:
-                objearth.plotshow(od[k][0],figsize=(6,6),title=od[k][1])
\ No newline at end of file
+                objearth.plotshow(od[k][0],figsize=(6,6),title=od[k][1])
+    def cloundcount(self,dataset,datarange=[352,480,944]):
+        ds = dataset.pixel_qa
+        s = xarray.where(ds==0,0,0)
+        for j in datarange:
+            x = xarray.where(ds==j,1,0)
+            s = s + x
+        count = (s!=0).sum()
+        return int(count)
+    def mincloud(self):
+        a = []
+        for i in range(self.ids.dims['time']):
+            pc = self.cloundcount(self.ids.isel(time=i))
+            a.append(pc)
+        c = a.index(min(a))
+        return self.ids.isel(time=c)
+
+
+
+
+
+
+
+
+
